==> redpesk-cli_3.15.0.orig.tar.gz: redpesk-cli-3.15.0/cmd/teams_constants.go <==
/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------
	// users command
	teamsCommand      = "teams"
	teamsCmdShortDesc = "Teams commands group"
	// -------------

	// List command
	teamsListCmdName         = "list"
	teamsListCmdAlias        = "ls"
	teamsListCmdShortUsage   = "List the teams from the Redpesk infrastructure"
	teamsListCmdHeader       = "ID\t Slug\t Name\t Status\t Number_of_members"
	teamsListCmdVerboseLine1 = "ID:\t"
	teamsListCmdVerboseLine2 = "Name:\t"
	teamsListCmdVerboseLine3 = "Status:\t"
	teamsListCmdVerboseLine4 = "Description:\t"
	teamsListCmdVerboseLine5 = "Owner:\t"
	teamsListCmdVerboseLine6 = "Members:"
	teamsListCmdVerboseLine7 = "Slug:\t"
	teamsListCmdVerboseLine8 = "Pseudo\t Email\t Invitation status"
	teamsListCmdVerboseLine9 = "Number_of_members:\t"

	teamsListVerboseLineNb = 7
	// -------------

	// Get command
	teamGetCmdName       = "get <team-ID>"
	teamGetCmdShortUsage = "Get the properties of a team"
	teamGetCmdLongUsage  = "Get the properties of the team identified by <team-ID>"
	// -------------

	// Add command
	teamAddCmdName       = "add"
	teamAddCmdShortUsage = "Create a new team"

	teamAddCmdAnsLine0 = "------ Team creation requested by user -----"
	teamAddCmdAnsLine1 = "Creation of \"%s\" team...\t"

	teamAddCmdNameFlag      = "name"
	teamAddCmdNameFlagAlias = "n"
	teamAddCmdNameFlagUsage = "[Mandatory] Name of the new team"

	teamAddCmdDescFlag      = "description"
	teamAddCmdDescFlagAlias = "d"
	teamAddCmdDescFlagUsage = "[Optional] Description of the new team"

	teamAddCmdPublicFlag      = "public"
	teamAddCmdPublicFlagUsage = "[Optional] If set, the team is created as a public team, if not as private"
	// -------------

	// Update command
	teamUpdateCmdName       = "update <team-ID>"
	teamUpdateCmdShortUsage = "Update a team settings"
	teamUpdateCmdLongUsage  = "Update the settings of the team identified by <team-ID>"

	teamUpdateCmdAnsLine0 = "------- Team update requested by user ------"
	teamUpdateCmdAnsLine1 = "Update of \"%s\" team...\t"
	// -------------

	// Invite command
	teamInviteCmdName       = "invite <team-ID> (--guest=<user-ID> | <otherTeam-ID>)"
	teamInviteCmdShortUsage = "Invite a user or a team in another team"
	teamInviteCmdLongUsage  = "Invite the user <user-ID> or the team <otherTeam-ID> in the team <team-ID>"

	teamInviteCmdGuestFlag      = "guest"
	teamInviteCmdGuestFlagAlias = "g"
	teamInviteCmdGuestFlagUsage = "[Mandatory] Guest to invite to the team"

	teamInviteCmdAnsLine0 = "------- Invitation requested by user -------"
	teamInviteCmdAnsLine1 = "Sending an invitation to \"%s\" to join \"%s\" team...\t"
	// -------------

	// Delete member command
	teamDelMemberCmdName       = "del-member <team-ID> (--member=<user-ID> | <otherTeam-ID>)"
	teamDelMemberCmdShortUsage = "Delete a member from a team"
	teamDelMemberCmdLongUsage  = "Delete the user <user-ID> or the team <otherTeam-ID> from the team <team-ID>"

	teamDelMemberCmdMemberFlag      = "member"
	teamDelMemberCmdMemberFlagAlias = "m"
	teamDelMemberCmdMemberFlagUsage = "[Mandatory] Member to delete from the team"

	teamDelMemberCmdAnsLine0 = "------- Member deletion requested by user -------"
	teamDelMemberCmdAnsLine1 = "Requesting the deletion of member \"%s\" from team \"%s\"...\t"
	// -------------

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	teamCreationInfoMsg = "Asking for the creation of the team: \"%s\""
	teamUpdateInfoMsg   = "Asking for the update of the team: \"%s\""

	// Error messages
	teamNameFlagNotSetShortMsg  = "Empty name for team during creation"
	teamNameFlagNotSetLongMsg   = "please provide a name for your team"
	teamGuessFlagNotSetShortMsg = "Empty guest name for invitation"
	teamGuessFlagNotSetLongMsg  = "please provide a guest name to invite, it can be a user or a team"

	teamIDNotSetMsg   = "No team ID argument in the command line"
	teamIDRequiredMsg = "An team ID is required for the wanted operation, please provide one"
	teamNotFoundMsg   = "Team not found. Either the team does not exist or you are not allowed to access it"

	noUsersInvitedMsg = "the invitation has not been sent because no users were found"

	teamIdentifierNotFound      = "no team has been found with the identifier \"%s\""
	teamGuestIdentifierNotFound = "no guest has been found with the identifier \"%s\""

	noMemberInTeamMsg    = "No member \"%s\" has been found in the team \"%s\""
	teamMemberNotDeleted = "a problem occurred, indeed the member has not been deleted correctly"

	// Debug messages
	teamCreationDebugMsg = "Asking for the creation of the team: %+v"
	teamUpdateDebugMsg   = "Asking for the update of the team: %+v"

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)

==> redpesk-cli_3.18.3.orig.tar.gz: redpesk-cli-3.18.3/cmd/teams_constants.go <==
/*
Copyright © 2020-2023 IoT.bzh Company
Contact: https://www.iot.bzh/licensing

This file is part of the redpesk-cli project, the redpesk command line tool.

$RP_BEGIN_LICENSE$
Commercial License Usage
 Licensees holding valid commercial IoT.bzh licenses may use this file in
 accordance with the commercial license agreement provided with the
 Software or, alternatively, in accordance with the terms contained in
 a written agreement between you and The IoT.bzh Company. For licensing terms
 and conditions see https://www.iot.bzh/terms-conditions. For further
 information use the contact form at https://www.iot.bzh/contact.

GNU General Public License Usage
 Alternatively, this file may be used under the terms of the GNU General
 Public license version 3. This license is as published by the Free Software
 Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
 of this file. Please review the following information to ensure the GNU
 General Public License requirements will be met
 https://www.gnu.org/licenses/gpl-3.0.html.
$RP_END_LICENSE$
*/

package cmd

const (
	// --------------------------------------------------------------
	// Subcommands and their subcommands ----------------------------
	// --------------------------------------------------------------
	// users command
	teamsCommand      = "teams"
	teamsCmdShortDesc = "Teams commands group"
	// -------------

	// List command
	teamsListCmdName         = "list"
	teamsListCmdAlias        = "ls"
	teamsListCmdShortUsage   = "List the teams from the Redpesk infrastructure"
	teamsListCmdHeader       = "ID\t Slug\t Name\t Status\t Number_of_members"
	teamsListCmdVerboseLine1 = "ID:\t"
	teamsListCmdVerboseLine2 = "Name:\t"
	teamsListCmdVerboseLine3 = "Status:\t"
	teamsListCmdVerboseLine4 = "Description:\t"
	teamsListCmdVerboseLine5 = "Owner:\t"
	teamsListCmdVerboseLine6 = "Members:"
	teamsListCmdVerboseLine7 = "Slug:\t"
	teamsListCmdVerboseLine8 = "Pseudo\t Email\t Invitation status"
	teamsListCmdVerboseLine9 = "Number_of_members:\t"

	teamsListVerboseLineNb = 7
	// -------------

	// Get command
	teamGetCmdName       = "get <team-ID>"
	teamGetCmdShortUsage = "Get the properties of a team"
	teamGetCmdLongUsage  = "Get the properties of the team identified by <team-ID>"
	// -------------

	// Add command
	teamAddCmdName       = "add"
	teamAddCmdShortUsage = "Create a new team"

	teamAddCmdAnsLine0 = "------ Team creation requested by user -----"
	teamAddCmdAnsLine1 = "Creation of \"%s\" team...\t"

	teamAddCmdNameFlag      = "name"
	teamAddCmdNameFlagAlias = "n"
	teamAddCmdNameFlagUsage = "[Mandatory] Name of the new team"

	teamAddCmdDescFlag      = "description"
	teamAddCmdDescFlagAlias = "d"
	teamAddCmdDescFlagUsage = "[Optional] Description of the new team"

	teamAddCmdPublicFlag      = "public"
	teamAddCmdPublicFlagUsage = "[Optional] If set, the team is created as a public team, if not as private"
	// -------------

	// Update command
	teamUpdateCmdName       = "update <team-ID>"
	teamUpdateCmdShortUsage = "Update a team settings"
	teamUpdateCmdLongUsage  = "Update the settings of the team identified by <team-ID>"

	teamUpdateCmdAnsLine0 = "------- Team update requested by user ------"
	teamUpdateCmdAnsLine1 = "Update of \"%s\" team...\t"
	// -------------

	// Invite command
	teamInviteCmdName       = "invite <team-ID> (--guest=<user-ID> | <otherTeam-ID>)"
	teamInviteCmdShortUsage = "Invite a user or a team in another team"
	teamInviteCmdLongUsage  = "Invite the user <user-ID> or the team <otherTeam-ID> in the team <team-ID>"

	teamInviteCmdGuestFlag      = "guest"
	teamInviteCmdGuestFlagAlias = "g"
	teamInviteCmdGuestFlagUsage = "[Mandatory] Guest to invite to the team"

	teamInviteCmdAnsLine0 = "------- Invitation requested by user -------"
	teamInviteCmdAnsLine1 = "Sending an invitation to \"%s\" to join \"%s\" team...\t"
	// -------------

	// Delete member command
	teamDelMemberCmdName       = "del-member <team-ID> (--member=<user-ID> | <otherTeam-ID>)"
	teamDelMemberCmdShortUsage = "Delete a member from a team"
	teamDelMemberCmdLongUsage  = "Delete the user <user-ID> or the team <otherTeam-ID> from the team <team-ID>"

	teamDelMemberCmdMemberFlag      = "member"
	teamDelMemberCmdMemberFlagAlias = "m"
	teamDelMemberCmdMemberFlagUsage = "[Mandatory] Member to delete from the team"

	teamDelMemberCmdAnsLine0 = "------- Member deletion requested by user -------"
	teamDelMemberCmdAnsLine1 = "Requesting the deletion of member \"%s\" from team \"%s\"...\t"
	// -------------

	// --------------------------------------------------------------
	// --------------------------------------------------------------

	// --------------------------------------------------------------
	// Messages -----------------------------------------------------
	// --------------------------------------------------------------

	// Information messages
	teamCreationInfoMsg = "Asking for the creation of the team: \"%s\""
	teamUpdateInfoMsg   = "Asking for the update of the team: \"%s\""

	// Error messages
	teamNameFlagNotSetShortMsg  = "Empty name for team during creation"
	teamNameFlagNotSetLongMsg   = "please provide a name for your team"
	teamGuessFlagNotSetShortMsg = "Empty guest name for invitation"
	teamGuessFlagNotSetLongMsg  = "please provide a guest name to invite, it can be a user or a team"

	teamIDNotSetMsg   = "No team ID argument in the command line"
	teamIDRequiredMsg = "An team ID is required for the wanted operation, please provide one"
	teamNotFoundMsg   = "Team not found. Either the team does not exist or you are not allowed to access it"

	noUsersInvitedMsg = "the invitation has not been sent because no users were found"

	teamIdentifierNotFound       = "no team has been clearly identified with \"%s\", check out the previous warning messages that may give you an explanation"
	teamIdentifierNotFoundOnTryX = "the team identifier '%s' has not been found on attempt #%d (filter: '%s')"
	tooManyTeamIDFoundOnTryX     = "too many team identifiers have been found on attempt #%d (filter: '%s'). Please try to use the slug/alias instead of the team name"

	teamGuestIdentifierNotFound = "no guest has been found with the identifier \"%s\""

	noMemberInTeamMsg    = "No member \"%s\" has been found in the team \"%s\""
	teamMemberNotDeleted = "a problem occurred, indeed the member has not been deleted correctly"

	// Debug messages
	teamCreationDebugMsg = "Asking for the creation of the team: %+v"
	teamUpdateDebugMsg   = "Asking for the update of the team: %+v"

	// --------------------------------------------------------------
	// --------------------------------------------------------------
)
